==> jc-1.4.0.tar.gz: gnu/xml/xpath/UnionExpr.h <==
// public final class gnu.xml.xpath.UnionExpr

// class file dependencies
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 4fc1b12fbb0cffd4 gnu_xml_xpath_Pattern
// @dep_class f653c26fdf5e1332 gnu_xml_xpath_UnionExpr
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Pattern

#include "gnu/xml/xpath/Pattern.h"

#ifndef _JC_gnu_xml_xpath_UnionExpr_H_
#define _JC_gnu_xml_xpath_UnionExpr_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_UnionExpr$sub_refs	_jc_gnu_xml_xpath_UnionExpr$sub_refs;
typedef struct _jc_gnu_xml_xpath_UnionExpr$sub_nonrefs	_jc_gnu_xml_xpath_UnionExpr$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_UnionExpr$refs	_jc_gnu_xml_xpath_UnionExpr$refs;
typedef struct _jc_gnu_xml_xpath_UnionExpr$nonrefs	_jc_gnu_xml_xpath_UnionExpr$nonrefs;
typedef struct _jc_gnu_xml_xpath_UnionExpr$object	_jc_gnu_xml_xpath_UnionExpr$object;

typedef const struct _jc_gnu_xml_xpath_UnionExpr$vmethods	_jc_gnu_xml_xpath_UnionExpr$vmethods;
typedef const struct _jc_gnu_xml_xpath_UnionExpr$vtable	_jc_gnu_xml_xpath_UnionExpr$vtable;
typedef const struct _jc_gnu_xml_xpath_UnionExpr$vtype	_jc_gnu_xml_xpath_UnionExpr$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_UnionExpr$method$_init$5fff2d0b57bc010b(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *, struct _jc_gnu_xml_xpath_Expr$object *, struct _jc_gnu_xml_xpath_Expr$object *);

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_xpath_UnionExpr$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_xpath_UnionExpr$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *, struct _jc_object *, jint, jint);
extern jboolean _jc_gnu_xml_xpath_UnionExpr$method$matches$bd70941b9693d4d7(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_UnionExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_UnionExpr$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_xpath_UnionExpr$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_xpath_UnionExpr$method_info$matches$bd70941b9693d4d7;
extern _jc_method _jc_gnu_xml_xpath_UnionExpr$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_UnionExpr$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *, struct _jc_object *, jint, jint);
	jboolean	(*matches$bd70941b9693d4d7)(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *);
};

// Vtable
struct _jc_gnu_xml_xpath_UnionExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_xpath_Pattern$vmethods	gnu_xml_xpath_Pattern;
	_jc_gnu_xml_xpath_UnionExpr$vmethods	gnu_xml_xpath_UnionExpr;
};

// Vtype
struct _jc_gnu_xml_xpath_UnionExpr$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_UnionExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_UnionExpr$sub_refs {
	struct _jc_gnu_xml_xpath_Expr$object	*lhs;
	struct _jc_gnu_xml_xpath_Expr$object	*rhs;
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_UnionExpr$refs {
    _jc_gnu_xml_xpath_UnionExpr$sub_refs	gnu_xml_xpath_UnionExpr;
    _jc_gnu_xml_xpath_Pattern$sub_refs	gnu_xml_xpath_Pattern;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_UnionExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_UnionExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_xpath_Pattern$sub_nonrefs	gnu_xml_xpath_Pattern;
    _jc_gnu_xml_xpath_UnionExpr$sub_nonrefs	gnu_xml_xpath_UnionExpr;
};

// Object instance structure
struct _jc_gnu_xml_xpath_UnionExpr$object {
	_jc_gnu_xml_xpath_UnionExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_UnionExpr$vtype	*vtype;
	_jc_gnu_xml_xpath_UnionExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_UnionExpr$vtype _jc_gnu_xml_xpath_UnionExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_UnionExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_UnionExpr$class_object;

#endif	/* _JC_gnu_xml_xpath_UnionExpr_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/UnionExpr.h <==
// public final class gnu.xml.xpath.UnionExpr

// class file dependencies
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 4fc1b12fbb0cffd4 gnu_xml_xpath_Pattern
// @dep_class f653c26fdf5e1332 gnu_xml_xpath_UnionExpr
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Pattern

#include "gnu/xml/xpath/Pattern.h"

#ifndef _JC_gnu_xml_xpath_UnionExpr_H_
#define _JC_gnu_xml_xpath_UnionExpr_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_UnionExpr$sub_refs	_jc_gnu_xml_xpath_UnionExpr$sub_refs;
typedef struct _jc_gnu_xml_xpath_UnionExpr$sub_nonrefs	_jc_gnu_xml_xpath_UnionExpr$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_UnionExpr$refs	_jc_gnu_xml_xpath_UnionExpr$refs;
typedef struct _jc_gnu_xml_xpath_UnionExpr$nonrefs	_jc_gnu_xml_xpath_UnionExpr$nonrefs;
typedef struct _jc_gnu_xml_xpath_UnionExpr$object	_jc_gnu_xml_xpath_UnionExpr$object;

typedef const struct _jc_gnu_xml_xpath_UnionExpr$vmethods	_jc_gnu_xml_xpath_UnionExpr$vmethods;
typedef const struct _jc_gnu_xml_xpath_UnionExpr$vtable	_jc_gnu_xml_xpath_UnionExpr$vtable;
typedef const struct _jc_gnu_xml_xpath_UnionExpr$vtype	_jc_gnu_xml_xpath_UnionExpr$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_UnionExpr$method$_init$5fff2d0b57bc010b(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *, struct _jc_gnu_xml_xpath_Expr$object *, struct _jc_gnu_xml_xpath_Expr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_xpath_UnionExpr$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_xpath_UnionExpr$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_xpath_UnionExpr$method$matches$bd70941b9693d4d7(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_UnionExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_UnionExpr$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_xpath_UnionExpr$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_xpath_UnionExpr$method_info$matches$bd70941b9693d4d7;
extern _jc_method _jc_gnu_xml_xpath_UnionExpr$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_UnionExpr$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
	jboolean	(*matches$bd70941b9693d4d7)(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_UnionExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_xpath_UnionExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_xpath_Pattern$vmethods	gnu_xml_xpath_Pattern;
	_jc_gnu_xml_xpath_UnionExpr$vmethods	gnu_xml_xpath_UnionExpr;
};

// Vtype
struct _jc_gnu_xml_xpath_UnionExpr$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_UnionExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_UnionExpr$sub_refs {
	struct _jc_gnu_xml_xpath_Expr$object	*lhs;
	struct _jc_gnu_xml_xpath_Expr$object	*rhs;
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_UnionExpr$refs {
    _jc_gnu_xml_xpath_UnionExpr$sub_refs	gnu_xml_xpath_UnionExpr;
    _jc_gnu_xml_xpath_Pattern$sub_refs	gnu_xml_xpath_Pattern;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_UnionExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_UnionExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_xpath_Pattern$sub_nonrefs	gnu_xml_xpath_Pattern;
    _jc_gnu_xml_xpath_UnionExpr$sub_nonrefs	gnu_xml_xpath_UnionExpr;
};

// Object instance structure
struct _jc_gnu_xml_xpath_UnionExpr$object {
	_jc_gnu_xml_xpath_UnionExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_UnionExpr$vtype	*vtype;
	_jc_gnu_xml_xpath_UnionExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_UnionExpr$vtype _jc_gnu_xml_xpath_UnionExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_UnionExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_UnionExpr$class_object;

#endif	/* _JC_gnu_xml_xpath_UnionExpr_H_ */
